### Best Box
Two Variable Optimization | ParametricSoln v0.2.1
by: Charlie Taylor | March 06, 2023

PRIOR TO MINIMIZE OPTIMIZATION
    ParametricSoln: Two Variable Optimization

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             a           12            5           15 Base Dimension of Cardboard  (in)
             b            8            2           10 Height of Box  (in)

     Figure of Merit: Box Surface Area (boxSurfArea) = 528 sqin <== Minimize

    ========================== OPTIMIZATION CONSTRAINTS =========================
          name         value        minimum   maximum
        Volume         1152          500 ------------ Box Volume
    ============================================================================

AFTER MINIMIZE OPTIMIZATION
    ParametricSoln: Two Variable Optimization

    ====================== OPTIMIZATION DESIGN VARIABLES =======================
          name         value        minimum   maximum
             a      9.99999            5           15 Base Dimension of Cardboard  (in)
             b      5.00001            2           10 Height of Box  (in)

     Figure of Merit: Box Surface Area (boxSurfArea) = 300 sqin <== Minimize

    ========================== OPTIMIZATION CONSTRAINTS =========================
          name         value        minimum   maximum
        Volume          500          500 ------------ Box Volume
    ============================================================================

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
a | 9.99999 | in | Base Dimension of Cardboard (in)
b | 5.00001 | in | Height of Box (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 500 | cuin | Box Volume (cuin) | >500 | ---
boxSurfArea | 300 | sqin | Box Surface Area (sqin) | --- | ---

System Sensitivity
Design Variables (nominal values)
Name | Value | Units | Description
a | 9.99999 | in | Base Dimension of Cardboard (in)
b | 5.00001 | in | Height of Box (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 500 | cuin | Box Volume (cuin) | >500 | ---
boxSurfArea | 300 | sqin | Box Surface Area (sqin) | --- | ---

System Sensitivity
Design Variables (nominal values)
Name | Value | Units | Description
a | 9.99999 | in | Base Dimension of Cardboard (in)
b | 5.00001 | in | Height of Box (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 500 | cuin | Box Volume (cuin) | >500 | ---
boxSurfArea | 300 | sqin | Box Surface Area (sqin) | --- | ---

Design Variable Summary
Design Variables (nominal values)
Name | Value | Units | Description
a | 9.99999 | in | Base Dimension of Cardboard (in)
b | 5.00001 | in | Height of Box (in)
Result Variables
Name | Value | Units | Description | Low Limit | High Limit
Volume | 500 | cuin | Box Volume (cuin) | >500 | ---
boxSurfArea | 300 | sqin | Box Surface Area (sqin) | --- | ---

    Parametric Solutions
    parasol v0.2.1
    contact: C. Taylor, cet@appliedpython.com